Struct RunningNode

pub struct RunningNode {
    pub(crate) last_address_rearrange: Instant,
    pub(crate) last_invs: HashMap<BlockHash, (Instant, Vec<u32>)>,
    pub(crate) inflight_filters: BTreeMap<u32, BlockFilter>,
}

Fields

last_address_rearrange: Instantlast_invs: HashMap<BlockHash, (Instant, Vec<u32>)>

To find peers with a good connectivity, keep track of what peers sent us an inv message for a block, in the first 5 seconds after we get the first inv message. If we ever decide to disconnect a peer, we should disconnect the ones that didn’t send us an inv message in a timely manner, but keep the ones that notified us of a new blocks the fastest. We also keep the moment we received the first inv message

inflight_filters: BTreeMap<u32, BlockFilter>