pub struct RunningNode {
pub(crate) last_address_rearrange: Instant,
pub(crate) last_invs: HashMap<BlockHash, (Instant, Vec<u32>)>,
pub(crate) inflight_filters: BTreeMap<u32, BlockFilter>,
}Fields
last_address_rearrange: Instantlast_invs: HashMap<BlockHash, (Instant, Vec<u32>)>To find peers with a good connectivity, keep track of what peers sent us an inv message for a block, in the first 5 seconds after we get the first inv message. If we ever decide to disconnect a peer, we should disconnect the ones that didn’t send us an inv message in a timely manner, but keep the ones that notified us of a new blocks the fastest. We also keep the moment we received the first inv message
inflight_filters: BTreeMap<u32, BlockFilter>Trait Implementations
Sourceimpl Clone for RunningNode
impl Clone for RunningNode
Sourcefn clone(&self) -> RunningNode
fn clone(&self) -> RunningNode
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RunningNode
impl Debug for RunningNode
Sourceimpl Default for RunningNode
impl Default for RunningNode
Sourceimpl NodeContext for RunningNode
impl NodeContext for RunningNode
Sourceconst REQUEST_TIMEOUT: u64 = 120u64
const REQUEST_TIMEOUT: u64 = 120u64
How long we wait for a peer to respond to our request
fn get_required_services(&self) -> ServiceFlags
Sourceconst MAX_OUTGOING_PEERS: usize = 10usize
const MAX_OUTGOING_PEERS: usize = 10usize
Max number of simultaneous connections we initiates we are willing to hold
Sourceconst ASK_FOR_PEERS_INTERVAL: u64 = 3_600u64
const ASK_FOR_PEERS_INTERVAL: u64 = 3_600u64
We ask for peers every ASK_FOR_PEERS_INTERVAL seconds
Sourceconst PEER_DB_DUMP_INTERVAL: u64 = 30u64
const PEER_DB_DUMP_INTERVAL: u64 = 30u64
Save our database of peers every PEER_DB_DUMP_INTERVAL seconds
Sourceconst TRY_NEW_CONNECTION: u64 = 10u64
const TRY_NEW_CONNECTION: u64 = 10u64
Attempt to open a new connection (if needed) every TRY_NEW_CONNECTION seconds
Sourceconst ASSUME_STALE: u64 = 900u64
const ASSUME_STALE: u64 = 900u64
If ASSUME_STALE seconds passed since our last tip update, treat it as stale
Sourceconst IBD_REQUEST_BLOCKS_AGAIN: u64 = 30u64
const IBD_REQUEST_BLOCKS_AGAIN: u64 = 30u64
While on IBD, if we’ve been without blocks for this long, ask for headers again
Sourceconst MAX_INFLIGHT_REQUESTS: usize = 1_000usize
const MAX_INFLIGHT_REQUESTS: usize = 1_000usize
Max number of simultaneous inflight requests we allow
Sourceconst FEELER_INTERVAL: u64 = 30u64
const FEELER_INTERVAL: u64 = 30u64
Interval at which we open new feeler connections
Sourceconst ADDRESS_REARRANGE_INTERVAL: u64 = 3_600u64
const ADDRESS_REARRANGE_INTERVAL: u64 = 3_600u64
Interval at which we rearrange our addresses
Sourceconst BLOCK_CHECK_INTERVAL: u64 = 300u64
const BLOCK_CHECK_INTERVAL: u64 = 300u64
How often we check if we haven’t missed a block
Sourceconst SEND_ADDRESSES_INTERVAL: u64 = 3_600u64
const SEND_ADDRESSES_INTERVAL: u64 = 3_600u64
How often we send our addresses to our peers
Sourceconst CONNECTION_TIMEOUT: u64 = 10u64
const CONNECTION_TIMEOUT: u64 = 10u64
How long should we wait for a peer to respond our connection request. This shouldn’t be
greater than
TRY_NEW_CONNECTION in order to clear timed-out requests at the same pace.Sourceconst BLOCKS_PER_GETDATA: usize = 5usize
const BLOCKS_PER_GETDATA: usize = 5usize
How many blocks we can ask in the same request
Sourceconst MAX_CONCURRENT_GETDATA: usize = 10usize
const MAX_CONCURRENT_GETDATA: usize = 10usize
How many concurrent GETDATA packages we can send at the same time
Sourceconst MAINTENANCE_TICK: Duration = _
const MAINTENANCE_TICK: Duration = _
How often we perform the main loop maintenance tasks (checking for timeouts, peers, etc.)
Sourceconst NEW_CONNECTIONS_BATCH_SIZE: usize = 4usize
const NEW_CONNECTIONS_BATCH_SIZE: usize = 4usize
How many connections we try at once